//
// LDASTools AL - A library collection to provide an abstraction layer
//
// Copyright (C) 2018 California Institute of Technology
//
// LDASTools AL is free software; you may redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 (GPLv2) of the
// License or at your discretion, any later version.
//
// LDASTools AL is distributed in the hope that it will be useful, but
// without any warranty or even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public
// License (GPLv2) for more details.
//
// Neither the names of the California Institute of Technology (Caltech),
// The Massachusetts Institute of Technology (M.I.T), The Laser
// Interferometer Gravitational-Wave Observatory (LIGO), nor the names
// of its contributors may be used to endorse or promote products derived
// from this software without specific prior written permission.
//
// You should have received a copy of the licensing terms for this
// software included in the file LICENSE located in the top-level
// directory of this package. If you did not, you can view a copy at
// http://dcc.ligo.org/M1500244/LICENSE
//

//!author: "Lee Samuel Finn"
//: test warning exception  class

#include <iostream>
#include <string>

#include "ldastoolsal/unittest.h"
#include "ldastoolsal/unimplemented_error.hh"

using LDASTools::Error::unimplemented_error;

using namespace std;  //introduces namespace std

LDASTools::Testing::UnitTest Test;

int
main(int ArgC, char** ArgV)
{	
    Test.Init ( ArgC , ArgV );
	if (Test.IsVerbose())
	{
		cout << "$Id: tUnimplemented.cc,v 1.3 2005/09/15 23:55:26 emaros Exp $" << endl;
	}
	
	// Throw the exception, catch it, and check its data
	
	const char* s = "unimplemented error";
	try {
	    throw unimplemented_error(s);
	} catch (unimplemented_error& x) {
		Test.Check(true, "caught unimplemented_error");  
		Test.Check(0 == strcmp(x.what(), s)) 
			<< s << " == " << x.what() << endl;
	} catch (bad_exception &x) {
		Test.Check(false,"caught bad exception");
	}
	Test.Exit(); 
}

